@@ -120,6 +120,12 @@ class ERDiagramGenerator(BaseGenerator):
         # Estado interno
         self._entities: List[EREntity] = []
         self._relationships: List[ERRelationship] = []
+    
+    def check_dependencies(self) -> None:
+        """
+        Verifica que las dependencias necesarias estén instaladas.
+        Lanza un error si falta alguna dependencia.
+        """
 
         # Valida que el formato sea soportado
         supported_formats = ['png', 'svg', 'pdf', 'dot', 'eps', 'ps']
@@ -128,8 +134,6 @@ class ERDiagramGenerator(BaseGenerator):
                 f"Formato '{self.format}' no soportado. "
                 f"Formatos disponibles: {', '.join(supported_formats)}"
             )
-        
-        #### Verificar dependencias
 
         # Verificar que Graphviz esté instalado en el sistema
         try:
@@ -205,6 +209,9 @@ class ERDiagramGenerator(BaseGenerator):
         Returns:
             str: Ruta del archivo generado
         """
+
+        # Verificar dependencias
+        self.check_dependencies()
         
         # Analizar modelos y crear entidades
         self.load_entities()
